/*
Copyright 2010-2012 Sergey Levin


This file is part of crosti.

Crosti is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Crosti is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with crosti.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef VIEWER_H
#define VIEWER_H

#include <QtGui>

#include "ui_fmview.h"
#include "schemedata.h"
#include "view.h"


class CViewPortWatcher;
class CMiniMap;


class CScaleBar:public QWidget
{
 Q_OBJECT

public:
   CScaleBar(QWidget* cntnt,QWidget *parent=0);
   ~CScaleBar();

   int scaleDefault()const{return SCALEDEFAULT;}
   void scaleChange(int dscale);

   Ui::fmview ui;


signals:
  void scaleChanged(qreal);


private slots:
   void scaleUp()   {scaleChange(KEYSTEP);}
   void scaleDown() {scaleChange(-KEYSTEP);}
   void setScale(int scl);
   void setScaleSB(int scale){ui.scaleSB->setValue(scale);}
   void scaleResetBtnPress(){ui.scaleSB->setValue(SCALEDEFAULT);}


private:
   const int SCALEDEFAULT,
             KEYSTEP;

   int _scaleMin,
       _scaleMax,
       _scale;

   QShortcut *scScaleUp,
             *scScaleDown,
             *scScaleReset;
};




class CViewer:public QWidget
{
 Q_OBJECT

 public:
   CViewer(QWidget *parent=0);
   virtual ~CViewer();
   virtual void updateMiniMap(CMiniMap *miniMap);
   virtual QImage image() const = 0;
   virtual void disconnectViewPortWatcher();

 protected:
   void wheelEvent(QWheelEvent *e);
   virtual CViewPortWatcher *viewPortWatcher() const = 0;

   QVBoxLayout *layout;
   CScaleBar   *scaleBar;

   const int MOUSESTEP;
};



#endif // VIEWER_H
